package org.isakiev.fileManager.contentManagers;

import org.isakiev.fileManager.entities.IDirEntity;
import org.isakiev.fileManager.entities.IEntity;

/**
 * Interface of content manager, which is used to fill the content of the model.
 * @author Isakiev Ruslan
 */
public interface IContentManager {
	
	/**
	 * Returns the root of file system tree with the children 
	 * (The children are the system root folders). 
	 * @return root of the file system tree
	 */
	public IDirEntity getRoot();
	
	/**
	 * Explores directory and specifies the children - files and subdirectories.
	 * @param dir directory to explore.
	 */
	public void exploreDir(IDirEntity dir);
	
	/**
	 * Renames / moves entity to the specified directory
	 * @param entity entity to rename / to move
	 * @param newName new name for this entity
	 * @param listener listens to the process events
	 * @return true if operation completed successfully
	 */
	public boolean renMove(IEntity entity, String newName, IProcessInfoListener listener);
	
	/**
	 * Copies entity. 
	 * @param entity entity to copy
	 * @param substring 
	 * @param replacement
	 * @param listener listens to the process events
	 */
	public void copy(IEntity entity, String substring, String replacement, IProcessInfoListener listener);
	
	/**
	 * Deletes the specified entity
	 * @param entity entity to delete
	 * @param listener listens to the process events
	 */
	public void delete(IEntity entity, IProcessInfoListener listener);
	
	/**
	 * Creates subdirectory with the specified name in the parent directory. 
	 * @param parentDirectory parent directory
	 * @param name new directory's name
	 * @return true if operation completed successfully
	 */
	public boolean createDirectory(IDirEntity parentDirectory, String name, IProcessInfoListener processInfoListener);

}
