package org.isakiev.fileManager.contentViewers.explorer;

import java.util.List;
import java.util.ArrayList;

import javax.swing.event.TreeModelListener;
import javax.swing.event.TreeModelEvent;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;

import org.isakiev.fileManager.contentModel.IContentModel;
import org.isakiev.fileManager.contentModel.IContentModelListener;
import org.isakiev.fileManager.entities.*;

/**
 * Tree model for visualization.
 * @author Isakiev Ruslan
 */
class ExplorerStyleTreeModel implements TreeModel {
	
	private IContentModel myContentModel;
	private ArrayList<TreeModelListener> myListeners;
	private IDirEntity myCurrentParent;
	private List<IEntity> myCurrentChildren;
	
	public ExplorerStyleTreeModel(IContentModel content){
		myContentModel = content;
		myContentModel.addModelListener(new MyContentModelListener());
		myListeners = new ArrayList<TreeModelListener>();
		myCurrentParent = null;
		myCurrentChildren = new ArrayList<IEntity>(0);
	}
	
	private void setCurrentParent(Object parent) {
		IDirEntity parentEntity = (IDirEntity) parent;
		if (!parentEntity.equals(myCurrentParent)) {
			myCurrentParent = parentEntity;
			myCurrentChildren = myContentModel.getChildren(parentEntity);
		}
	}
	
	public Object getRoot() {
		return myContentModel.getRoot();
	}

	public int getChildCount(Object parent) {
		setCurrentParent(parent);
		return myCurrentChildren.size();
		
		//List<IEntity> children = myContent.getChildren((IDirEntity)parent);
		//return children.size();
	}
	
	public Object getChild(Object parent, int index) {
		setCurrentParent(parent);
		return myCurrentChildren.get(index);
		
		//List<IEntity> children = myContent.getChildren((IDirEntity)parent);
		//return children.get(index);
	}
	
	public int getIndexOfChild(Object parent, Object child) {
		setCurrentParent(parent);
		
		int index = 0;
		for (IEntity e:myCurrentChildren) {
			if (e.equals(child)) {
				return index;
			}
			index++;
		}
		return -1;
		
		/*List<IEntity> children = myContent.getChildren((IDirEntity)parent);
		int index = 0;
		for (IEntity e:children ) {
			if (e.equals(child)) {
				return index;
			}
			index++;
		}
		return -1; */
	}
	
	public boolean isLeaf(Object node) {
		return !((IEntity)node).hasChildren();
	}

	public void valueForPathChanged(TreePath path, Object value) {
		//unused
	}

	public void addTreeModelListener(TreeModelListener tml) {
		myListeners.add(tml);
	}
	
	public void removeTreeModelListener(TreeModelListener tml) {
		myListeners.remove(tml);
	}
	
	public void fireStructureChanged(TreePath path) {
		for (TreeModelListener tml:myListeners) {
			tml.treeStructureChanged(new TreeModelEvent(this, path));
		}
	}
	
	private class MyContentModelListener implements IContentModelListener{
		public void contentModelDataChanged() {
			fireStructureChanged(new TreePath(getRoot()));
		}
		public void entityWasRenamed(IEntity entity, IEntity renamedEntity) {}
	}
}
