package org.isakiev.fileManager.contentViewers.nc;

import javax.swing.*;
import java.awt.event.*;
import java.awt.*;

import org.isakiev.fileManager.entities.*;
import org.isakiev.fileManager.utils.Settings;
import org.isakiev.fileManager.utils.Tools;

public class NCStyleEntityViewerPanel extends JPanel{
	
	private IPanelDispatcher myDispatcher;
	private NCStyleEntityViewerPanel myInstance;
	private IEntity myEntity;
	private String myTopTitle;
	
	public NCStyleEntityViewerPanel(IEntity entity, JComponent component,
			                 IPanelDispatcher dispatcher, boolean showInfo) {
		
		myDispatcher = dispatcher;
		myEntity = entity;
		myTopTitle = (entity != null ? entity.toString() : "");
		
		setFocusable(true);
		setLayout(new GridLayout(1,1));
		setBackground(Settings.getInstance().getBackgroundColor());
		
		JPanel pane = new JPanel(new BorderLayout());
		pane.setBackground(Settings.getInstance().getBackgroundColor());

		if (showInfo) {
			pane.add(createInfoLabel(entity), BorderLayout.PAGE_START);
		}

		pane.add(component, BorderLayout.CENTER);
		add(pane);
		
		setBorder(NCStyleBorderFactory.createNCBorder(
				Settings.getInstance().getTextColor(),
				Settings.getInstance().getFont(),
				" "+myTopTitle+" ", " press ESC to close "));
		
		myInstance = this;
		addComponentListener(new PanelResizeListener());
		addKeyListener(new EscListener());
	}
	
	public NCStyleEntityViewerPanel(String topTitle, JComponent component, IPanelDispatcher dispatcher) {
		this(null, component, dispatcher, false);
		myTopTitle = topTitle;
	}
	
	private void updateTitledBorder() {
		int width = this.getWidth() - 40;
		String bottomTitle = "press ESC to close";
		String space = " ";
		setBorder(NCStyleBorderFactory.createNCBorder(
				Settings.getInstance().getTextColor(),
				Settings.getInstance().getFont(),
				space + correctString(myTopTitle, width) + space,
				space + correctString(bottomTitle, width) + space));
	}
	
	private int getStringWidth(String s, Font font) {
		FontMetrics metrics = getFontMetrics(font);
		return metrics.stringWidth(s);
	}
	
	private String fitString(String s, int width, Font font) {
		if (s.length() == 0) {
			return "";
		}
		
		FontMetrics metrics = getFontMetrics(Settings.getInstance().getFont());
		char[] chars = new char[s.length()];
		s.getChars(0,s.length(),chars,0);
		int count = 0;
		int totalWidth = metrics.charWidth(chars[0]);
		while (totalWidth < width) {
			count++;
			totalWidth += metrics.charWidth(chars[count]);
		}
		return s.substring(0,count);
	}
	
	private String correctString(String s, int width) {
		
		Font font = Settings.getInstance().getFont();
		if (getStringWidth(s,font) < width) {
			return s;
		} else {
			String mark = "...";
			int markWidth = getStringWidth(mark,font);
			return fitString(s, width - markWidth, font) + mark;
		}
	}
	
	private static JLabel createInfoLabel(IEntity entity) {
		//Creating label
		JLabel info = new JLabel();
		info.setVerticalAlignment(JLabel.TOP);
		info.setHorizontalAlignment(JLabel.LEFT);
		//info.setOpaque(false);
		
		//Creating information to be displayed
		StringBuffer buffer = new StringBuffer();
		buffer.append("<html><table border=0 cellspacing=0 cellpadding=0 width=100%><tr><td colspan=2>");
		buffer.append("<font color=#00FF00>&nbsp;&nbsp;").append(entity.toString()).append("</font></td></tr>");
		
		if (entity.isDirEntity()) {
			//if not the tree root
			if (entity.getParent() != null) {
				buffer.append("<tr><td>&nbsp;&nbsp;Entity type:</td><td>&nbsp;&nbsp;Directory</td></tr>");
				buffer.append("<tr><td>&nbsp;&nbsp;Last modified:</td>");
				buffer.append("<td>&nbsp;&nbsp;").append(Tools.getDateTimeString(entity.getFile().lastModified())).append("</td></tr>");
			}
		} else if (entity.isFileEntity()) {
			buffer.append("<tr><td>&nbsp;&nbsp;Entity type:</td><td>&nbsp;&nbsp;File</td></tr>");
			buffer.append("<tr><td>&nbsp;&nbsp;File type:</td><td>&nbsp;&nbsp;").append(((IFileEntity)entity).getType().getDescription()).append("</td></tr>");
			buffer.append("<tr><td>&nbsp;&nbsp;File size:</td><td>&nbsp;&nbsp;").append(Tools.getFileSizeString(entity.getSize())).append("</td></tr>");
			buffer.append("<tr><td>&nbsp;&nbsp;Last modified:</td><td>&nbsp;&nbsp;" + Tools.getDateTimeString(entity.getLastModified())).append("</td></tr>");
		} else if (entity.isDiskEntity()) {
			buffer.append("<tr><td>&nbsp;&nbsp;Entity type:</td><td>&nbsp;&nbsp;Disk</td></tr>");
		}
		buffer.append("</table></html>");
		info.setText(buffer.toString());

		info.setFont(Settings.getInstance().getInfoFont());
		info.setBackground(Settings.getInstance().getBackgroundColor());
		info.setForeground(Color.WHITE);
		return info;
	}
	
	private class EscListener extends KeyAdapter {
		public void keyPressed(KeyEvent ke) {
			if (ke.getKeyCode() == KeyEvent.VK_ESCAPE ||
				ke.getKeyCode() == KeyEvent.VK_ENTER) {
				myDispatcher.restoreDefaultComponent(myInstance);
			}
		}
	}
	
	/**
	 * This class is used to update border after panel's resize
	 */
	private class PanelResizeListener extends ComponentAdapter {
		public void componentResized(ComponentEvent e) {
			updateTitledBorder();
		}
	}
}
