package org.isakiev.fileManager.entities;

import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.isakiev.fileManager.FileManagerException;
import org.isakiev.fileManager.entityTypes.IEntityType;

/**
 * The class reperesents directory.
 * @author Isakiev Ruslan.
 */
class DirEntity extends Entity implements IDirEntity{
	
	private boolean myExplored;
	private ArrayList<? extends IEntity> myChildren;
	
	/**
	 * Main constructor
	 * @param file file or directory pathname
	 * @param parent parent in the tree
	 */
	public DirEntity(File file, IEntity parent, IEntityType type) {
		super(file, parent, type);
		myExplored = false;
		myChildren = null;;
	}
	
	/**
	 * Checks whether the directory was explored
	 * @return result of the check
	 */
	public boolean isExplored() {
		return myExplored;
	}
	
	/**
	 * Sets new list of the children for current entity.
	 * @param children new list of the children.
	 */
	public void setChildren(ArrayList<? extends IEntity> children) {
		myChildren = children;
		myExplored = true;
	}
	
	/**
	 * Returns an array of the current entity's children.
	 * @return an array of the current entity's children.
	 */
	public List<IEntity> getChildren() {
		if (!myExplored) {
			throw new FileManagerException("Can't get children from unexplored directory!");
		}
		return Collections.unmodifiableList(myChildren);
	}
	
	/**
	 * Checks if the Entity is DirEntity
	 * @return check result
	 */
	public boolean isDirEntity() {
		return true;
	}
	
	/**
	 * Checks if Entity has children.
	 * @return check result
	 */
	public boolean hasChildren() {
		return true;
	}
	
}
