package org.isakiev.fileManager.entities;

import java.io.File;

import org.isakiev.fileManager.entityTypes.IEntityType;

/**
 * Basic interface, a tree node, representing file system entity (directory, file etc.)
 * @author Isakiev Ruslan
 */
public interface IEntity {
	
	/**
	 * Returns <code>File</code> assigned to this entity. 
	 * @return <code>File</code> assigned to this entity.
	 */
	public File getFile();
	
	/**
	 * Returns parent in the tree.
	 * @return parent in the tree.
	 */
	public IEntity getParent();
	
	/**
	 * Returns the type of current class
	 * @return the type of current class
	 */
	public IEntityType getType();
	
	/**
	 * Returns short entity name. It displayed in viewers.
	 * @return short entity name
	 */
	public String getShortName();
	
	/**
	 * Returns full entity name.
	 * @return full entity name.
	 */
	public String getFullName();
	
	/**
	 * Returns date when entity was last modified.
	 * @return date when entity was last modified.
	 */
	public long getLastModified();
	
	/**
	 * Returns entity size. 
	 * @return 0 if entity is a directory and entity size otherwise.
	 */
	public long getSize();
	
	/**
	 * Returns <code>true</code> if entity is an archive
	 * @return <code>true</code> if entity is an archive
	 */
	public boolean isArchiveEntity();
	
	/**
	 * Returns <code>true</code> if entity is compressed entity
	 * @return <code>true</code> if entity is compressed entity
	 */
	public boolean isCompressedEntity();
	
	/**
	 * Returns <code>true</code> if entity is file entity
	 * @return <code>true</code> if entity is file entity
	 */
	public boolean isFileEntity();
	
	/**
	 * Returns <code>true</code> if entity is directory entity
	 * @return <code>true</code> if entity is directory entity
	 */
	public boolean isDirEntity();
	
	/**
	 * Returns <code>true</code> if entity is disk entity
	 * @return <code>true</code> if entity is disk entity
	 */
	public boolean isDiskEntity();
	
	/**
	 * Checks if entity is the file system's tree root.
	 * @return result of the check;
	 */
	public boolean isTreeRoot();
	
	/**
	 * Checks if Entity has children.
	 * @return check result
	 */
	public boolean hasChildren();

}
