package org.isakiev.fileManager.entityTypes;

import org.isakiev.fileManager.entities.IEntity;
import org.isakiev.fileManager.utils.Tools;

import java.util.ArrayList;
import javax.swing.JComponent;


/**
 * This class is automatically generated according to information in XML file.
 * @author Isakiev Ruslan
 */
class AutomaticallyGeneratedType extends AbstractType {
	
	private int myPriority;
	private String myName;
	private String myDescription;
	private IEntityViewer myViewer;
	private boolean myArchiveFlag;
	private boolean myExecutableFlag;
	
	private boolean myDefineByFormat;
	private int myMinFileSize;
	private ArrayList<int[]> myKeyBytes;
	private String myExtension;

	public AutomaticallyGeneratedType() {
		myPriority = Integer.MAX_VALUE;
		myName = "";
		myDescription = "";
		myViewer = EmptyViewer.getInstance();
		myArchiveFlag = false;
		myExecutableFlag = false;
		
		myDefineByFormat = false;
		myExtension = "###";
		myKeyBytes = new ArrayList<int[]>();
		myMinFileSize = 0;
	}
	
	public boolean isArchive() {
		return myArchiveFlag;
	}
	
	public void setArchiveFlag(boolean flag) {
		myArchiveFlag = flag;
	}
	
	public boolean isExecutable() {
		return myExecutableFlag;
	}
	
	public void setExecutableFlag(boolean flag) {
		myExecutableFlag = flag;
	}
	
	public void setDefineByFormat(boolean value) {
		myDefineByFormat = value;
	}
	
	public void setExtension(String extension) {
		myExtension = extension;
	}
	
	public void setMinFileSize(int minFileSize) {
		myMinFileSize = minFileSize;
	}
	
	public void addKeyByte(int position, int value) {
		int[] entry = new int[2];
		entry[0] = position;
		entry[1] = value;
		myKeyBytes.add(entry);
	}
	
	public boolean checkFile(FileInfo info) {
		if (myDefineByFormat) {
			if (info.hasErrors() || info.getBufferLength() < myMinFileSize) {
				return false;
			} else {
				boolean ok = true;
				for (int[] pair:myKeyBytes) {
					ok &= (info.getUnsignedByteValue(pair[0]) == pair[1]);
				}
				return ok;
			}
		} else {
			return info.getFile().getName().endsWith("." + myExtension);
		}
	}
	
	public void setIcon(String iconPath) {
		setIcon(Tools.getTools().loadIcon(iconPath));
	}
	
	public int getPriority() {
		return myPriority;
	}

	public String getName() {
		return myName;
	}

	public String getDescription() {
		return myDescription;
	}
	
	public IEntityViewer getViewer() {
		return myViewer;
	}
	
	public void setPriority(int priority) {
		myPriority = priority;
	}
	
	public void setName(String name) {
		myName = name;
	}

	public void setDescription(String description) {
		myDescription = description;
	}

	public void setViewer(IEntityViewer viewer) {
		myViewer = viewer;
	}
	

}
