package org.isakiev.fileManager.entityTypes;

import java.io.*;
import java.util.logging.*;

import org.isakiev.fileManager.FileManagerException;
/**
 * This class creates info used to recognize file type.
 * @author Isakiev Ruslan
 */
class FileInfo {
	
	private File myFile;
	private static final int BUFFER_SIZE = 1024; 
	private byte[] myBuffer;
	private int myActualLength;
	private boolean myErrorFlag = false;
	
	public FileInfo(File file) {
		myFile = file;
		myBuffer = new byte[BUFFER_SIZE];
		FileInputStream fis = null;
		myActualLength = BUFFER_SIZE;
		if (myFile.length() < BUFFER_SIZE) {
			myActualLength = new Long(myFile.length()).intValue();
		}
		try {
			fis = new FileInputStream(myFile);
			int number = fis.read(myBuffer, 0, myActualLength);
			if (number != myActualLength) {
				myErrorFlag = true;
				logWarningMessage("Reading file \""+file.getAbsolutePath()+"\": Wrong number of read bytes: "+number+" instead of "+myActualLength);
				return;
			}
		} catch (IOException ioe) {
			logWarningMessage("Reading file \""+file.getAbsolutePath()+"\": IOException: "+ioe.getMessage());
			myErrorFlag = true;
		} finally {
			try {
				if (fis != null) 
					fis.close();
			} catch (IOException e) { /*Ignore*/ }
		}
	}
	
	private void logWarningMessage(String message) {
		Logger logger = Logger.getLogger("org.isakiev.fileManager");
		logger.warning(message);
	}
	
	public FileInfo(byte[] bytes) {
		myBuffer = bytes;
		myActualLength = bytes.length;
		myFile = null;
	}
	
	public File getFile() {
		return myFile;
	}
	
	public int getBufferLength() {
		return myActualLength;
	}
	
	public byte getSignedByteValue(int index) {
		if ((index < 0) || (index >= myActualLength)) {
			throw new FileManagerException("Getting info for recognizing file type: index out of bounds: "+index);
		}
		return myBuffer[index];
	}
	
	public int getUnsignedByteValue(int index) {
		if ((index < 0) || (index >= myActualLength)) {
			throw new FileManagerException("Getting info for recognizing file type: index out of bounds: "+index);
		}
		
		//getting from signed byte unsigned byte value
		if (myBuffer[index] < 0) {
			return 255-(~myBuffer[index]);
		} else {
			return myBuffer[index];
		}
	}
	
	public boolean hasErrors() {
		return myErrorFlag;
	}
	
	
	

}
