package org.isakiev.fileManager.entityTypes;

import javax.swing.Icon;
import java.awt.Color;

public interface IEntityType {
	
	/**
	 * Gets file format name.
	 * @return file format name
	 */
	public String getName();
	
	/**
	 * Gets file type description.
	 * @return description
	 */
	public String getDescription();
	
	/**
	 * Checks if this file type describes an archive.
	 * @return result of the check.
	 */
	public boolean isArchive();
	
	/**
	 * Checks if this file is an executable one.
	 * @return result of the check.
	 */
	public boolean isExecutable();
	
	/**
	 * Gets color to be used in NC style viewer for this file type.
	 * @return color for NC style viewer
	 */
	public Color getColorForNCViewer();
	
	/**
	 * Gets icon, associated to this file type.
	 * @return icon
	 */
	public Icon getIcon();
	
	/**
	 * Returns viewer for this type of entities.
	 * @return viewer 
	 */
	public IEntityViewer getViewer();
	
}
