package org.isakiev.fileManager.tests;

import junit.framework.TestCase;
import java.util.*;
import java.io.*;

import org.isakiev.fileManager.archives.*;
import org.isakiev.fileManager.entities.*;
import org.isakiev.fileManager.entityTypes.*;

/**
 * Tests for archives
 * @author Ruslan Isakiev
 */
public class TestArchives extends TestCase {
	
	private static String myArchivesDir = "4tests/archives/";
	
	private String traceEntityTree(String prefix, IEntity entity) {
		StringBuffer buffer = new StringBuffer();
		buffer.append(prefix);
		buffer.append(entity.getShortName());
		buffer.append("\n");
		if (entity.hasChildren()) {
			List <IEntity> children = ((IDirEntity)entity).getChildren();
			for (IEntity e:children) {
				buffer.append(traceEntityTree(prefix+entity.getShortName()+"#", e));
			}
		}
		return buffer.toString();
	}
	
	public void testZipContent1() {
		IArchiveManager zip = ZipArchiveManager.getInstance();
		File file = new File(myArchivesDir + "archive1.zip");
		IEntity root = EntityFactory.createGlobalRootDirEntity();
		IEntityType type = EntityTypeContainer.getInstance().getFileType(file);
		IDirEntity archive = EntityFactory.createArchiveEntity(file,root,type);
		zip.exploreArchive(archive);
		String actual = traceEntityTree("", archive);
		String expected = "archive1.zip\n"+
						  "archive1.zip#file1.file\n"+
						  "archive1.zip#file2.file\n"+
						  "archive1.zip#file3.file\n"+
						  "archive1.zip#file4.file\n";
		assertEquals("Wrong archive's content!", expected, actual);
	}
	
	public void testZipContent2() {
		IArchiveManager zip = ZipArchiveManager.getInstance();
		File file = new File(myArchivesDir + "archive2.zip");
		IEntity root = EntityFactory.createGlobalRootDirEntity();
		IEntityType type = EntityTypeContainer.getInstance().getFileType(file);
		IDirEntity archive = EntityFactory.createArchiveEntity(file,root,type);
		zip.exploreArchive(archive);
		String actual = traceEntityTree("", archive);
		String expected = "archive2.zip\n"+
						  "archive2.zip#dir1\n"+
						  "archive2.zip#dir1#dir11\n"+
						  "archive2.zip#dir1#dir12\n"+
						  "archive2.zip#dir1#dir12#file1.file\n"+
						  "archive2.zip#dir1#dir12#file2.file\n"+
						  "archive2.zip#dir1#dir12#file3.file\n"+
						  "archive2.zip#dir1#dir12#file4.file\n"+
						  "archive2.zip#dir1#dir13\n"+
						  "archive2.zip#dir2\n"+
						  "archive2.zip#dir2#file1.file\n"+
						  "archive2.zip#dir2#file4.file\n"+
						  "archive2.zip#file1.file\n"+
						  "archive2.zip#file2.file\n"+
						  "archive2.zip#file3.file\n"+
						  "archive2.zip#file4.file\n";

		assertEquals("Wrong archive's content!", expected, actual);
	}
	
	public void testZipParent() {
		IArchiveManager zip = ZipArchiveManager.getInstance();
		File file = new File(myArchivesDir + "archive2.zip");
		IEntity root = EntityFactory.createGlobalRootDirEntity();
		IEntityType type = EntityTypeContainer.getInstance().getFileType(file);
		IDirEntity archive = EntityFactory.createArchiveEntity(file,root,type);
		zip.exploreArchive(archive);
		assertEquals("Can't find archive entity's parent!", root, archive.getParent());
	}
	
	private class IntEnum implements Enumeration {
		int current = -1;
		public boolean hasMoreElements() {
			return current<10;
		}
        public Integer nextElement() {
        	if (current<10) {
        		current++;
        	}
        	return current;
        }
	}
	
	public void testPushBackEnum1() {
		Enumeration<Integer> e = new IntEnum();
		PushBackEnum<Integer> pbe = new PushBackEnum<Integer>(e);
		for (int i=0; i<5; i++) {
			pbe.nextEntry();
		}
		final int n = 3;
		Integer[] values = new Integer[n];
		for (int i=0; i<n; i++) {
			values[i] = pbe.nextEntry();
		}
		for (int i=0; i<n; i++) {
			pbe.pushBackEntry(values[i]);
		}
		assertEquals("Incorrect work of PushBackEnum! (1)", new Integer(7), pbe.nextEntry());
	}
	
	public void testPushBackEnum2() {
		Enumeration<Integer> e = new IntEnum();
		PushBackEnum<Integer> pbe = new PushBackEnum<Integer>(e);
		Integer value = null;
		for (int i=0; i<3; i++) {
			value = pbe.nextEntry();
		}
		pbe.pushBackEntry(value);
		assertEquals("Incorrect work of PushBackEnum! (2)", value,pbe.nextEntry());
	}
	
	public void testPushBackEnum3() {
		Enumeration<Integer> e = new IntEnum();
		PushBackEnum<Integer> pbe = new PushBackEnum<Integer>(e);
		final int n = 4;
		for (int i=0; i<n; i++) {
			pbe.nextEntry();
		}
		pbe.pushBackEntry(new Integer(25));
		pbe.nextEntry();
		pbe.nextEntry();
		assertEquals("Incorrect work of PushBackEnum! (3)", new Integer(5), pbe.nextEntry());
	}
	
}
