package org.isakiev.fileManager.tests;

import junit.framework.TestCase;
import java.io.File;

import org.isakiev.fileManager.entityTypes.*;

/**
 * Tests file type definition.
 * @author Isakiev Ruslan
 */
public class TestEntityTypes extends TestCase {
	
	private EntityTypeContainer myContainer;
	private static String myExamplesPath = "4tests/files/";
	
	/**
	 * Default constructor. Creates file type container.
	 */
	public TestEntityTypes() {
		myContainer = EntityTypeContainer.getInstance();
	}
	
	/**
	 * Tests txt file type.
	 */
	public void testFileTypeTxt() {
		File text  = new File(myExamplesPath + "text.txt");
		assertEquals("Wrong file type (text.txt) ", "text", myContainer.getFileType(text).getName());
	}
	
	/**
	 * Tests JPEG file type.
	 */
	public void testFileTypeJpeg() {
		File file = new File(myExamplesPath + "jpeg_example");
		assertEquals("Can't recognize JPEG", "jpeg", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests GIF file type.
	 */
	public void testFileTypeGif87a() {
		File file = new File(myExamplesPath + "gif87_example");
		assertEquals("Can't recognize GIF 87a", "gif", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests GIF file type.
	 */
	public void testFileTypeGif89a() {
		File file = new File(myExamplesPath + "gif89_example");
		assertEquals("Can't recognize GIF 89a", "gif", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests PNG file type.
	 */
	public void testFileTypePng() {
		File file = new File(myExamplesPath + "png_example");
		assertEquals("Can't recognize PNG", "png", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests TIFF file type.
	 */
	public void testFileTypeTiff() {
		File file = new File(myExamplesPath + "tiff_example");
		assertEquals("Can't recognize TIFF", "tiff", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests WAV file type.
	 */
	public void testFileTypeWav() {
		File file  = new File(myExamplesPath + "wav_example");
		assertEquals("Can't recognize WAV ", "wav", myContainer.getFileType(file).getName());
	}
	
	
	/**
	 * Tests MP3 file type (v1).
	 */
	public void testFileTypeMp3_v1() {
		File file  = new File(myExamplesPath + "mp3_firstbytes1");
		assertEquals("Can't recognize MP3 ", "mp3", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests MP3 file type (v2).
	 */
	public void testFileTypeMp3_v2() {
		File file  = new File(myExamplesPath + "mp3_firstbytes2");
		assertEquals("Can't recognize MP3 ", "mp3", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests ZIP file type.
	 */
	public void testFileTypeZip() {
		File file  = new File(myExamplesPath + "zip_example");
		assertEquals("Can't recognize ZIP ", "zip", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests RAR file type.
	 */
	public void testFileTypeRar() {
		File file  = new File(myExamplesPath + "rar_example");
		assertEquals("Can't recognize RAR ", "rar", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests EXE file type.
	 */
	public void testFileTypeExe() {
		File file  = new File(myExamplesPath + "example.exe");
		assertEquals("Can't recognize EXE ", "exe", myContainer.getFileType(file).getName());
	}
	
	/**
	 * Tests unknown file type.
	 */
	public void testFileTypeUnknown() {
		File file  = new File(myExamplesPath + "unknownFormat.ico");
		assertEquals("Wrong file type (unknownFormat.ico) ", "unknown", myContainer.getFileType(file).getName());
	}
}
