package org.isakiev.fileManager.tests;

import java.util.List;

import junit.framework.TestCase;

import org.isakiev.fileManager.contentModel.*;
import org.isakiev.fileManager.entities.*;
import org.isakiev.fileManager.contentManagers.*;

/**
 * Model tests.
 * @author Isakiev Ruslan
 */
public class TestModel extends TestCase {
	
	
	/**
	 * Tests if stored data is correct. [Tests ContentModel.getRoot()]
	 */
	public void testData1() {
		IContentModel model = new ContentModel(new ContentManagerTestEdition());
		
		//Testing ContentModel.getRoot()
		IDirEntity root = model.getRoot();
		List<IEntity> children = root.getChildren();

		assertEquals("Wrong number of root's children.",3,children.size());
		
		assertEquals("Wrong root child!", "x:\\", children.get(0).getFile().toString());
		assertEquals("Wrong root child!", "y:\\", children.get(1).getFile().toString());
		assertEquals("Wrong root child!", "z:\\", children.get(2).getFile().toString());
	
	}
	
	/**
	 * Tests if stored data is correct. [Tests ContentModel.getChildren(parent)]
	 */
	public void testData2() {
		IContentModel model = new ContentModel(new ContentManagerTestEdition());
		
		IDirEntity root = model.getRoot();
		List<IEntity> children = root.getChildren();

		//Testing ContentModel.getChildren(parent)
		for (int i=0; i<3; i++) {
			IDirEntity current = (IDirEntity) children.get(i);
			for (int j=0; j<5; j++) {
				List<IEntity> currentChildren = model.getChildren(current);
				assertEquals("Wrong child name!", "abc", currentChildren.get(0).getFile().getName());
				assertEquals("Wrong child name!", "klm", currentChildren.get(1).getFile().getName());
				assertEquals("Wrong child name!", "123.bmp", currentChildren.get(2).getFile().getName());
				assertEquals("Wrong child name!", "456.txt", currentChildren.get(3).getFile().getName());
				
				assertTrue("Incorrect child type!", currentChildren.get(0).isDirEntity());
				assertTrue("Incorrect child type!", currentChildren.get(1).isDirEntity());
				assertTrue("Incorrect child type!", currentChildren.get(2).isFileEntity());
				assertTrue("Incorrect child type!", currentChildren.get(3).isFileEntity());
				
				//Test subdirectory
				current = (IDirEntity) currentChildren.get(i % 2);
			}
		}
		
	}
	
	
	/**
	 * Tests if model reqests already existing directory.
	 */
	/*public void testDynamicFilling() {
		Logger logger = new Logger();
		IContentModel model = new ContentModel(new ContentManagerWithLog(logger));
		IDirEntity root = model.getRoot();
		List<IEntity> children = root.getChildren();
		
		IDirEntity dir1 = (IDirEntity) children.get(0);
		children = model.getChildren(dir1);
		IDirEntity dir2 = (IDirEntity) children.get(2);
		children = model.getChildren(dir2);
		IDirEntity dir3 = (IDirEntity) children.get(1);
		children = model.getChildren(dir3);
		
		//Getting children again
		model.getChildren(dir2);
		model.getChildren(dir1);
		model.getChildren(dir3);
		
		//Checking if the model asked manager to explore this directories twice  
		if (logger.hasEqualRecords()) 
			fail("Exploring already explored directory!");
	}*/
	
	/**
	 * Tests if ContentModel return null when trying to define entity by unknown path
	 */
	/*public void testDefiningEntinyByPath() {
		ContentModel model = new ContentModel(new ContentManagerLinuxStyle());
		String path = "/first/second/second/file.file";
		IEntity entity = model.getEntity(path,"/");
		// was uncorrectly defined by path
		assertEquals("Entity", path, entity.getFile().getAbsolutePath());
	}*/
	
	/**
	 * Tests if ContentModel return root directory when trying to define entity by unknown path
	 */
	/*public void testDefiningEntinyByUnknownPath() {
		IContentModel model = new ContentModel(new ContentManagerLinuxStyle());
		IEntity entity = model.getEntity("!@#$SomeUnexistingEntity/szdf/7234.txt");
		assertEquals("Entity was uncorrectly defined by unexisting path!", model.getRoot(), entity);
	}*/

}
