package org.isakiev.fileManager.utils;

import java.awt.Color;
import java.awt.Font;

/**
 * Contains file manager's settings. 
 * @author Isakiev Ruslan
 *
 */
public class Settings {
	
	private Font myFont = new Font("Verdana", Font.PLAIN, 16); 
	private Font myInfoFont = new Font("Verdana", Font.PLAIN, 12); 
	private Color myBackgroundColor = new Color(0,0,128,255);
	private Color mySelectionColor = new Color(0,128,128,255);
	private Color myTextColor = Color.CYAN;
	private Color myDirectoryColor = Color.WHITE;
	private Color myArchiveFileColor = Color.MAGENTA; //new Color(255,0,255,255);
	private Color myExecutableFileColor = Color.GREEN;
	private Color myHiddenFileColor = new Color(0,128,128,255);
	
	
	private int myNCPanelCellHeight = 20;
	
	private static Settings myInstance = null;
	
	/**
	 * Private constructor.
	 */
	private Settings() {
	}
	
	public static Settings getInstance() {
		if (myInstance == null) {
			myInstance = new Settings();
		}
		return myInstance;
	}
	
	/**
	 * Gets the mininmum frame height 
	 * @return mininmum frame height
	 */
	public static int getMinFrameHeight() {
		return 150;
	}
	
	/**
	 * Gets the mininmum frame width 
	 * @return mininmum frame width
	 */
	public static int getMinFrameWidth() {
		return 240;
	}
	
	
	/**
	 * Returns font used for NC style panel
	 * @return font used for NC style panel
	 */
	public Font getFont() {
		return myFont;
	}
	
	/**
	 * Returns font used for information in NC style panel
	 * @return font used for information in NC style panel
	 */
	public Font getInfoFont() {
		return myInfoFont;
	}
	
	/**
	 * Returns background color for NC style panel
	 * @return background color for NC style panel
	 */
	public Color getBackgroundColor() {
		return myBackgroundColor;
	}
	
	/**
	 * Returns selection color for NC style panel
	 * @return selection color for NC style panel
	 */
	public Color getSelectionColor() {
		return mySelectionColor;
	}
	
	/**
	 * Returns text color for NC style panel
	 * @return text color for NC style panel
	 */
	public Color getTextColor() {
		return myTextColor;
	}
	
	/**
	 * Returns color for directories in NC style panel
	 * @return color for directories in NC style panel
	 */
	public Color getDirectoryColor() {
		return myDirectoryColor;
	}
	
	/**
	 * Returns color for archive files in NC style viewer
	 * @return color for archive files in NC style viewer
	 */
	public Color getArchiveFileColor() {
		return myArchiveFileColor;
	}
	
	/**
	 * Returns color for executable files in NC style viewer
	 * @return color for executable files in NC style viewer
	 */
	public Color getExecutableFileColor() {
		return myExecutableFileColor;
	}
	
	/**
	 * Returns color for executable files in NC style viewer
	 * @return color for executable files in NC style viewer
	 */
	public Color getHiddenFileColor() {
		return myHiddenFileColor;
	}
	
	/**
	 * Returns cell size for NC style panel
	 * @return cell size for NC style panel
	 */
	public int getNCPanelCellHeight() {
		return myNCPanelCellHeight;
	}
	
	
	

}
